<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>商品详情</title>
    <meta content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0" name="viewport">
    <link rel="shortcut icon" href="./favicon.ico">
    <meta name="apple-mobile-web-app-capable" content="yes">
    <meta name="apple-mobile-web-app-status-bar-style" content="black">
    <link rel="stylesheet" href="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/css/sm.min.css">
    <link rel="stylesheet" href="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/css/sm-extend.min.css">
    <!--<link rel="stylesheet" href="./css/page/index.css"/>-->
    <link rel="stylesheet" href="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/css/common.css"/>
    <link rel="stylesheet" href="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/css/page/products_content.css"/>
</head>
<body>
<div class="page-group" id="products_content">
    <div class="page page-current" id="products_contents">
        <header class="bar bar-nav">
            <span class="icon icon-left pull-left back"></span>

            <h1 class="title">商品详情</h1>
        </header>
        <!--导航栏-->
        <nav class="bar bar-tab">
            <a class="tab-item external just_buy open-popup" id="just_buy">
                <span class="tab-label">立即购买</span>
            </a>
        </nav>
        <!-- 这里是页面内容区 -->
        <div class="content infinite-scroll infinite-scroll-bottom" data-distance="1">
            <div class="swiper-container" id="content_swiper">
                <div class="swiper-wrapper">
                    <?php
                    $tpl_helper = new tpl_detail($output);
                    $tpl_helper->ads_baner();
                    ?>
                </div>
                <div class="swiper-pagination"></div>
            </div>
            <div class="content-padded">
                <?php
                $tpl_helper = new tpl_detail($output);
                $show_id = $tpl_helper->search_show_id();
                $tpl_helper->show_summary($show_id);
                ?>
            </div>
            <div class="br"></div>
            <div class="content-padded">

            </div>
            <div class="list-block">
                <ul>
                    <li class="item-content">
                        <div class="item-inner">
                            <div class="item-title">产品参数</div>
                        </div>
                    </li>
                    <?php
                    $tpl_helper = new tpl_detail($output);
                    $tpl_helper->show_attrs();
                    ?>
                </ul>
            </div>
            <div class="br"></div>
            <!-- 加载提示符 -->
            <div class="infinite-scroll-preloader">
                <div class="preloader"></div>
            </div>
            <div class="list-container"></div>
        </div>
    </div>
    <!--立即购买-->
    <div class="popup">
        <div class="list-block">
            <?php
            $tpl_helper = new tpl_detail($output);
            $show_id = $tpl_helper->search_show_id();
            $tpl_helper->show_pop($show_id);
            ?>
            <form action="<?php echo MOBILE_SITE_URL;?>/index.php?client_type=wap&act=member_buy&op=step_first" method="post">
                <input type="hidden" name="goods_id" value="" id="goods_id"/>
                <input type="hidden" name="number" value="" id="number"/>
                <input type="hidden" name="cart_id" value="" id="cart_id"/>
                <div class="established" id="established">
                    <input type="submit" value="确定" style="display: inline-block;width: 100%; height: 100%;font-size: 0.85rem"/>
                </div>
            </form>
            <div class="close close-popup"></div>
        </div>
        <div class="small_img">
            <img src=" <?php echo $output['common_info']['images'][0] ; ?> " alt=""/>
        </div>
    </div>
</div>
<script type="text/javascript">
    var data=<?php
        echo joutput_data($output);
    ?>
</script>
<script type="text/javascript" src="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/js/common/zepto.min.js"></script>
<script type="text/javascript" src="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/js/common/sm.min.js"></script>
<script type="text/javascript" src="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/js/common/sm-extend.min.js"></script>
<script type="text/javascript" src="<?php echo RESOURCE_SITE_URL; ?>/mobile/mshop/js/page/products_content.js"></script>
<script src="http://res.wx.qq.com/open/js/jweixin-1.0.0.js"></script>
<script type="text/javascript">

    var bonus_title = "熊猫美妆" ;
    var sub_title = "给你想要的化妆品";
    var url_host=window.location.hostname;
    var url = "http://" + url_host + "/mobile/index.php?act=goods_common&op=goods_detail&client_type=wap&goods_id=" + "<?php
            echo $output['summary']['0']['goods_id'].'&goods_commonid='.$output['summary']['0']['goods_commonid'];
            ?>";
    var img_url = "<?php echo $output['common_info']['images'][0];?>";

    weiXinShare.init({
        title:bonus_title,
        desc:sub_title,
        link:url,
        imgUrl:img_url
    });

</script>
</body>
</html>
